==> afnix_2.8.0.orig.tar.gz: afnix-src-2.8.0/src/srv/svg/shl/SvgGroup.cpp <==
// ---------------------------------------------------------------------------
// - SvgGroup.cpp                                                            -
// - afnix:svg service - svg group node class implementation                 -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2017 amaury darsch                                   -
// ---------------------------------------------------------------------------

#include "SvgGroup.hpp"
#include "Runnable.hpp"
#include "QuarkZone.hpp"
#include "Exception.hpp"

namespace afnix {

  // -------------------------------------------------------------------------
  // - private section                                                       -
  // -------------------------------------------------------------------------

  // the svg node name
  static const String XML_TAG_NAME = "svg:g";

  // -------------------------------------------------------------------------
  // - class section                                                         -
  // -------------------------------------------------------------------------

  // create a group

  SvgGroup::SvgGroup (void) : SvgStyling (XML_TAG_NAME) {
    d_eflg = false;
  }

  // return the class name

  String SvgGroup::repr (void) const {
    return "SvgGroup";
  }

  // -------------------------------------------------------------------------
  // - object section                                                        -
  // -------------------------------------------------------------------------

  // create a new object in a generic way

  Object* SvgGroup::mknew (Vector* argv) {
    long argc = (argv == nilp) ? 0 : argv->length ();
    // check for 0 argument
    if (argc == 0) return new SvgGroup;
    // wrong arguments
    throw Exception ("argument-error", 
		     "too many arguments with svg group constructor");
  }
}

==> afnix_2.9.0.orig.tar.gz: afnix-src-2.9.0/src/srv/svg/shl/SvgGroup.cpp <==
// ---------------------------------------------------------------------------
// - SvgGroup.cpp                                                            -
// - afnix:svg service - svg group node class implementation                 -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2019 amaury darsch                                   -
// ---------------------------------------------------------------------------

#include "SvgGroup.hpp"
#include "Runnable.hpp"
#include "QuarkZone.hpp"
#include "Exception.hpp"

namespace afnix {

  // -------------------------------------------------------------------------
  // - private section                                                       -
  // -------------------------------------------------------------------------

  // the svg node name
  static const String XML_TAG_NAME = "svg:g";

  // -------------------------------------------------------------------------
  // - class section                                                         -
  // -------------------------------------------------------------------------

  // create a group

  SvgGroup::SvgGroup (void) : SvgStyling (XML_TAG_NAME) {
    d_eflg = false;
  }

  // return the class name

  String SvgGroup::repr (void) const {
    return "SvgGroup";
  }

  // -------------------------------------------------------------------------
  // - object section                                                        -
  // -------------------------------------------------------------------------

  // create a new object in a generic way

  Object* SvgGroup::mknew (Vector* argv) {
    long argc = (argv == nullptr) ? 0 : argv->length ();
    // check for 0 argument
    if (argc == 0) return new SvgGroup;
    // wrong arguments
    throw Exception ("argument-error", 
		     "too many arguments with svg group constructor");
  }
}
